<?php
/**
 * A class definition responsible for processing and mapping product according to feed rules and make the feed
 *
 * @link       https://webappick.com/
 * @since      1.0.0
 *
 * @package    Woo_Feed
 * @subpackage Woo_Feed/includes
 * @author     Nashir Uddin <nasir.webappick@gmail.com>
 */

use CTXFeed\V5\Notice\Notices;

class Woo_Feed_Notices {

	/**
	 * @var Woo_Feed_Notices
	 */
	protected static $instance;

	/**
	 * Holds Notices Message
	 *
	 * @var array
	 */
	protected static $notices_message = array(
		'woo_feed_attributes'       => array(
			'title'   => false,
			'message' => '<span class="dashicons dashicons-bell"></span> <strong>You have updated WooCommerce product attributes. Please clear the CTX Feed cache to generate a new feed.</strong>',
		),
		'woo_feed_product_count'    => array(
			'title'   => false,
			'message' => '<span class="dashicons dashicons-bell"></span> <strong>You have published WooCommerce products more than 50K.</strong>',
		),
		'enable_multi_currency'     => array(
			'title'   => '<strong>Currency</strong>',
			'message' => '<strong>You have updated Woocommerce WPML currency set to Geolocation.</strong>',
		),
		'base_conversion_rate'      => array(
			'title'   => '<strong>Conversion</strong>',
			'message' => '<strong>The base conversion rate is not set for each currency.</strong>',
		),
		'upload_dicrotory_writable' => array(
			'title'   => '<strong>Writable</strong>',
			'message' => '<strong>Please allow to write permission of wordpress upload directory .</strong>',
		),

	);


	/**
	 * Holds Notices
	 *
	 * @var array
	 */
	private $notices = array();

	/**
	 * The prefix we'll be using for the option/user-meta.
	 *
	 * @access public static
	 * @var string
	 */
	public static $prefix = 'wf_dismissed';

	/**
	 * Get Woo_Feed_Notices Singleton Instance
	 *
	 * @return Woo_Feed_Notices
	 */
	public static function getInstance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * Woo_Feed_Notices constructor.
	 * Initialize default messages and notices
	 *
	 * @return void
	 */
	private function __construct() {

		$this->woo_feed_upload_directory_check();
		$this->set_woo_feed_notices();

	}


	public function woo_feed_upload_directory_check() {
		$upload_dir = wp_upload_dir();
		$type       = 'upload_dicrotory_writable';
		if ( ! is_writable( dirname( $upload_dir['basedir'] ) ) ) {

			$notice_data = $this->get_woo_feed_notice_data();
			if ( empty( $notice_data ) ) {

				$this->add_woo_feed_notice_data( $type, 1 );

			} else {
				$this->update_woo_feed_notice_data( $type, $notice_data, 1 );
				$this->update_woo_feed_notice_dismiss( $type, false );
			}
		} else {
			self::update_woo_feed_notice_dismiss( $type, true );
		}
	}

	/**
	 * Declare the notices array with title and message.
	 *
	 * @access public
	 * @return void
	 */

	public function get_woo_feed_notices_message( $key, $value ) {
		if ( $value === 'title' ) {
			return self::$notices_message[ $key ]['title'];
		} else {
			return self::$notices_message[ $key ]['message'];
		}
	}

	/**
	 * Get the notices array from database.
	 *
	 * @access public
	 * @return array
	 */

	public static function get_woo_feed_notice_data() {
		return get_option( 'woo_feed_notices' );
	}

	/**
	 * Add the notices array into database.
	 *
	 * @access public
	 * @return void
	 */

	public static function add_woo_feed_notice_data( $type, $value ) {
		$notice_data[ $type ] = $value;
		add_option( 'woo_feed_notices', $notice_data, '', 'no' );
	}

	/**
	 * Update the notices array .
	 *
	 * @access public
	 * @return void
	 */

	public static function update_woo_feed_notice_data( $type, $notice_data, $value ) {

		//error_log( print_r( self::$prefix . '_' . $type, true ) );

		if ( ! array_key_exists( $type, $notice_data ) ) {
			$new_data[ $type ] = $value;
			$notice_all_data   = array_merge( $notice_data, $new_data );
			update_option( 'woo_feed_notices', $notice_all_data, '', 'no' );

		}
	}

	/**
	 * Update  dismiss status into database.
	 *
	 * @access public
	 * @return void
	 */

	public static function update_woo_feed_notice_dismiss( $type, $dismiss ) {

		//error_log( print_r( self::$prefix . '_' . $type, true ) );

		update_option( self::$prefix . '_' . $type, $dismiss, false );
	}

	/**
	 * Set the notices data .
	 *
	 * @access private
	 * @return void
	 */

	private function set_woo_feed_notices() {

		$wf_v5_notices = new Notices();
		//error_log( print_r( self::$notices_message, true ) );
		$this->notices = get_option( 'woo_feed_notices' );

		$options = array(
			'option_prefix' => self::$prefix,   // Change the user-meta prefix.
		);
		if ( is_array( $this->notices ) ) {
			foreach ( $this->notices as $key => $data ) {
				if ( array_key_exists( $key, self::$notices_message ) ) {

					$wf_v5_notices->add( $key, __( $this->get_woo_feed_notices_message( $key, 'title' ), 'woo_feed' ), __( $this->get_woo_feed_notices_message( $key, 'message' ), 'woo_feed' ), $options );
					$wf_v5_notices->boot();
				}
			}
		}

	}
	/**
	 * Add or update the notices data to databse.
	 *
	 * @access public
	 * @return void
	 */
	public static function add_update_woo_feed_notice_data( $type, $notice_data ) {
		//error_log( print_r( $type, true ) );
		if ( empty( $notice_data ) ) {
			self::add_woo_feed_notice_data( $type, 1 );
		} else {
			self::update_woo_feed_notice_data( $type, $notice_data, 1 );
			self::update_woo_feed_notice_dismiss( $type, false );
		}
	}



}


